Page 99 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 99

Home

    As time passed, the list of American businessmen
    cooperating with the Soviets grew to include the heads of
    some of the largest corporations in the United States. For
    a more detailed study on this subject we recommend
    Antony C. Sutton's book The Best Enemy Money Can
    Buy, published by Liberty House Press, Billings,
    Montana.

    To understand why wealthy businessmen in the
    United States have helped to establish and sustain what

    is commonly known as Communism, it is helpful to
    define some terms relative to the various economic

    systems of the 20 th century.

    Communism is defined by The American Heritage
    Dictionary as, "A social system characterized by the
    absence of classes and by common ownership of the
    means of production and subsistence." No nation existing
    during the 20th century fits this definition of
    Communism. There have been many communistic
    experiments (several in the U. S.) in which a community
    of people has voluntarily attempted to live together under
    such a system; however, none of these have ever been
    successful in improving the quality of life or remaining in
    existence for a long period.

    Communism, as laid down by Karl Marx in The
    Communist Manifesto, was a call to establish Socialism.
    His ten point plan for the takeover of industrialized
    nations included. Abolition of private property, a
    graduated income tax, abolition of right of inheritance,
    government confiscation of property, a national banking

    94

    The Secret Side of History

    Communism.